@@ -54,10 +54,12 @@ namespace Opal {
 
       subscriber (const Opal::Account & _account,
                   Opal::H323::EndPoint& _manager,
+                  bool _registering,
                   const PSafePtr<OpalPresentity> & _presentity)
         : PThread (1000, AutoDeleteThread),
         account (_account),
         manager (_manager),
+        registering (_registering),
         presentity (_presentity)
       {
         this->Resume ();
@@ -65,14 +67,23 @@ namespace Opal {
 
       void Main ()
         {
-          if (presentity && !presentity->IsOpen ())
-            presentity->Open ();
-          manager.Register (account);
+          if (registering) {
+            if (presentity && !presentity->IsOpen ())
+              presentity->Open ();
+            manager.Register (account);
+          } else {
+            manager.Unregister (account);
+
+            if (presentity && presentity->IsOpen ())
+              presentity->Close ();
+
+          }
         };
 
   private:
       const Opal::Account & account;
       Opal::H323::EndPoint& manager;
+      bool registering;
       const PSafePtr<OpalPresentity> & presentity;
     };
   };
@@ -96,7 +107,7 @@ Opal::H323::EndPoint::EndPoint (Opal::CallManager & _manager, Ekiga::ServiceCore
   set_listen_port (listen_port);
 
   /* Ready to take calls */
-  manager.AddRouteEntry("h323:.* = pc:<db>");
+  manager.AddRouteEntry("h323:.* = pc:*");
   manager.AddRouteEntry("pc:.* = h323:<da>");
 }
 
@@ -285,7 +296,7 @@ Opal::H323::EndPoint::subscribe (const Opal::Account & account,
   if (account.get_protocol_name () != "H323")
     return false;
 
-  new subscriber (account, *this, presentity);
+  new subscriber (account, *this, true, presentity);
 
   return true;
 }
@@ -298,7 +309,7 @@ Opal::H323::EndPoint::unsubscribe (const Opal::Account & account,
   if (account.get_protocol_name () != "H323")
     return false;
 
-  new subscriber (account, *this, presentity);
+  new subscriber (account, *this, false, presentity);
 
   return true;
 }
@@ -307,13 +318,9 @@ Opal::H323::EndPoint::unsubscribe (const Opal::Account & account,
 void
 Opal::H323::EndPoint::Register (const Opal::Account& account)
 {
-  PString gatekeeperID;
   std::string info;
-  std::string aor = account.get_aor ();
 
-  bool unregister = !account.is_enabled ();
-
-  if (!unregister && !IsRegisteredWithGatekeeper (account.get_host ())) {
+  if (account.is_enabled () && !IsRegisteredWithGatekeeper (account.get_host ())) {
 
     H323EndPoint::RemoveGatekeeper (0);
 
@@ -322,16 +329,16 @@ Opal::H323::EndPoint::Register (const Opal::Account& account)
       AddAliasName (manager.GetDefaultDisplayName ());
     }
 
-    SetGatekeeperPassword (account.get_password ());
+    SetGatekeeperPassword (account.get_password (), account.get_username ());
     SetGatekeeperTimeToLive (account.get_timeout () * 1000);
-    bool result = UseGatekeeper (account.get_host (), gatekeeperID);
+    bool result = UseGatekeeper (account.get_host ());
 
     // There was an error (missing parameter or registration failed)
     // or the user chose to not register
     if (!result) {
 
       // Registering failed
-      if (gatekeeper) {
+      if (GetGatekeeper () != NULL) {
 
         switch (gatekeeper->GetRegistrationFailReason ()) {
 
@@ -369,16 +376,13 @@ Opal::H323::EndPoint::Register (const Opal::Account& account)
       Ekiga::Runtime::run_in_main (boost::bind (&Opal::H323::EndPoint::registration_event_in_main, this, boost::cref (account), Account::Registered, std::string ()));
     }
   }
-  else if (unregister && IsRegisteredWithGatekeeper (account.get_host ())) {
-    /*
+}
 
-       H323EndPoint::RemoveGatekeeper (0);
-       RemoveAliasName (account.get_username ());
 
-    // Signal 
-    Ekiga::Runtime::run_in_main (boost::bind (&Opal::H323::EndPoint::registration_event_in_main, this, boost::cref (account), Ekiga::Account::Unregistered, std::string ()));
-     */
-  }
+void
+Opal::H323::EndPoint::Unregister (const Opal::Account& account)
+{
+  RemoveGatekeeper (account.get_host ());
 }
 
 
@@ -387,12 +391,16 @@ Opal::H323::EndPoint::UseGatekeeper (const PString & address,
                                      const PString & domain,
                                      const PString & iface)
 {
-  bool result =
-    H323EndPoint::UseGatekeeper (address, domain, iface);
+  bool result = false;
 
-  PWaitAndSignal m(gk_name_mutex);
+  if (!IsRegisteredWithGatekeeper (address)) {
+    result = H323EndPoint::UseGatekeeper (address, domain, iface);
 
-  gk_name = address;
+    if (result) {
+      PWaitAndSignal m(gk_name_mutex);
+      gk_name = address;
+    }
+  }
 
   return result;
 }
@@ -422,11 +430,21 @@ Opal::H323::EndPoint::OnIncomingConnection (OpalConnection & connection,
 					    G_GNUC_UNUSED unsigned options,
 					    G_GNUC_UNUSED OpalConnection::StringOptions *stroptions)
 {
-  PTRACE (3, "EndPoint\tIncoming connection");
+  bool busy = false;
+
+  PTRACE (3, "Opal::H323::EndPoint\tIncoming connection");
+
+  if (!H323EndPoint::OnIncomingConnection (connection, options, stroptions))
+    return false;
+
+  for (PSafePtr<OpalConnection> conn(connectionsActive, PSafeReference); conn != NULL; ++conn) {
+    if (conn->GetCall().GetToken() != connection.GetCall().GetToken() && !conn->IsReleased ())
+      busy = true;
+  }
 
   if (!forward_uri.empty () && manager.get_unconditional_forward ())
     connection.ForwardCall (forward_uri);
-  else if (manager.GetCallCount () > 1) {
+  else if (busy) {
 
     if (!forward_uri.empty () && manager.get_forward_on_busy ())
       connection.ForwardCall (forward_uri);
