@@ -203,6 +203,11 @@ Opal::Account::Account (Ekiga::ServiceCore & _core,
     enable ();
 }
 
+Opal::Account::~Account ()
+{
+  if (presentity)
+    presentity->SetPresenceChangeNotifier (OpalPresentity::PresenceChangeNotifier(0));
+}
 
 const std::string Opal::Account::as_string () const
 {
@@ -348,8 +353,10 @@ void Opal::Account::disable ()
     h323_endpoint->unsubscribe (*this, presentity);
   else
 #endif
-    sip_endpoint->unsubscribe (*this, presentity);
-
+    {
+      sip_endpoint->unsubscribe (*this, presentity);
+      sip_endpoint->Unsubscribe (SIPSubscribe::MessageSummary, get_aor ());
+    }
   // Translators: this is a state, not an action, i.e. it should be read as
   // "(you are) unregistered", and not as "(you have been) unregistered"
   status = _("Unregistered");
@@ -383,7 +390,7 @@ SIPRegister::CompatibilityModes Opal::Account::get_compat_mode () const
 void Opal::Account::remove ()
 {
   dead = true;
-  if (state == Registered) {
+  if (state == Registered || state == Processing) {
     disable();
     return;
   }
@@ -646,9 +653,13 @@ Opal::Account::handle_registration_event (RegistrationState state_,
           presentity->SubscribeToPresence (PString (*iter));
         }
         presentity->SetLocalPresence (personal_state, presence_status);
+        if (type != Account::H323) {
+          sip_endpoint->Subscribe (SIPSubscribe::MessageSummary, 3600, get_aor ());
+        }
       }
       if (presence_core && personal_details)
 	presence_core->publish (personal_details);
+
       state = state_;
       failed_registration_already_notified = false;
       updated ();
@@ -706,9 +717,9 @@ Opal::Account::handle_registration_event (RegistrationState state_,
         sip_endpoint->subscribe (*this, presentity);
         break;
       case SIPRegister::e_CannotRegisterPrivateContacts:
-        // CannotRegMC did not work, try next compat mode
+        // CannotRegPC did not work, try next compat mode
         compat_mode = SIPRegister::e_HasApplicationLayerGateway;
-        PTRACE (4, "Register failed in CannotRegisterMultipleContacts mode, retrying in HasApplicationLayerGateway mode");
+        PTRACE (4, "Register failed in CannotRegisterPrivateContacts mode, retrying in HasApplicationLayerGateway mode");
         sip_endpoint->subscribe (*this, presentity);
         break;
       case SIPRegister::e_HasApplicationLayerGateway:
