@@ -51,6 +51,13 @@
 
 #include <stdlib.h>
 
+// opal manages its endpoints itself, so we must be wary
+struct null_deleter
+{
+ void operator()(void const *) const
+ { }
+};
+
 static  bool same_codec_desc (Ekiga::CodecDescription a, Ekiga::CodecDescription b)
 {
   return (a.name == b.name && a.rate == b.rate);
@@ -103,6 +110,8 @@ using namespace Opal;
 CallManager::CallManager (Ekiga::ServiceCore & _core)
   : core (_core)
 {
+  stun_thread = 0;
+
   /* Initialise the endpoint parameters */
 #if P_HAS_IPV6
   char * ekiga_ipv6 = getenv("EKIGA_IPV6");
@@ -159,6 +168,8 @@ CallManager::CallManager (Ekiga::ServiceCore & _core)
 
 CallManager::~CallManager ()
 {
+  if (stun_thread)
+    stun_thread->WaitForTermination ();
   ClearAllCalls (OpalConnection::EndedByLocalUser, true);
   ShutDownEndpoints ();
 
@@ -529,10 +540,10 @@ void CallManager::set_stun_server (const std::string & server)
 void CallManager::set_stun_enabled (bool enabled)
 {
   stun_enabled = enabled;
-  if (stun_enabled) {
+  if (stun_enabled && !stun_thread) {
 
     // Ready
-    new StunDetector (stun_server, *this, queue);
+    stun_thread = new StunDetector (stun_server, *this, queue);
     patience = 20;
     Ekiga::Runtime::run_in_main (boost::bind (&CallManager::HandleSTUNResult, this), 1);
   } else
@@ -707,7 +718,7 @@ CallManager::create_call_in_main (Opal::Call* call)
 {
   boost::shared_ptr<Ekiga::CallCore> call_core = core.get<Ekiga::CallCore> ("call-core");
 
-  call_core->add_call (boost::shared_ptr<Opal::Call>(call),
+  call_core->add_call (boost::shared_ptr<Opal::Call>(call, null_deleter()),
 		       boost::dynamic_pointer_cast<CallManager>(shared_from_this ()));
 }
 
@@ -806,6 +817,7 @@ CallManager::HandleSTUNResult ()
     PSTUNClient::NatTypes result
       = (PSTUNClient::NatTypes)(GPOINTER_TO_UINT (g_async_queue_pop (queue))-1);
     got_answer = true;
+    stun_thread = 0;
 
     if (result == PSTUNClient::SymmetricNat
 	|| result == PSTUNClient::BlockedNat
