@@ -337,6 +337,7 @@ gm_accounts_window_update_account (GtkWidget *accounts_window,
 
       self->priv->toolbar.reset ();
       account->populate_menu (self->priv->toolbar);
+      populate_menu (accounts_window);
     }
   }
 }
@@ -571,6 +572,7 @@ accounts_window_new (Ekiga::ServiceCore &core)
   self = (AccountsWindow *) g_object_new (ACCOUNTS_WINDOW_TYPE, NULL);
   self->priv = new AccountsWindowPrivate (core);
   vbox = gtk_vbox_new (FALSE, 2);
+  gtk_window_set_title (GTK_WINDOW (self), _("Accounts"));
 
   /* The menu */
   menu_bar = gtk_menu_bar_new ();
