@@ -45,7 +45,7 @@
 #include "gm-smiley-chooser-button.h"
 
 #include "gm-smileys.h"
-#include "toolbox/toolbox.h"
+#include "toolbox.h"
 
 #include <string.h>
 #include <stdarg.h>
@@ -558,7 +558,7 @@ message_activated_cb (G_GNUC_UNUSED GtkWidget *w,
   // if ...-shift-enter, insert newline
   // if enter, send message
   // note there are two enter: from main kbd and from keypad
-  if ((key->keyval == GDK_Return || key->keyval == GDK_KEY_KP_Enter)
+  if ((key->keyval == GDK_Return || key->keyval == GDK_KP_Enter)
       && (key->state & GDK_SHIFT_MASK) == 0) {
 
     buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (self->priv->message));
