@@ -669,7 +669,7 @@ gm_pw_init_h323_page (GtkWidget *prefs_window,
 
   entry =
     gnome_prefs_entry_new (subsection, _("Forward _URI:"), H323_KEY "forward_host", _("The host where calls should be forwarded if call forwarding is enabled"), 1, false);
-  if (!strcmp (gtk_entry_get_text (GTK_ENTRY (entry)), ""))
+  if (!g_strcmp0 (gtk_entry_get_text (GTK_ENTRY (entry)), ""))
     gtk_entry_set_text (GTK_ENTRY (entry), "h323:");
 
   /* Packing widget */
@@ -717,7 +717,7 @@ gm_pw_init_sip_page (GtkWidget *prefs_window,
 
   entry =
     gnome_prefs_entry_new (subsection, _("Forward _URI:"), SIP_KEY "forward_host", _("The host where calls should be forwarded if call forwarding is enabled"), 1, false);
-  if (!strcmp (gtk_entry_get_text (GTK_ENTRY (entry)), ""))
+  if (!g_strcmp0 (gtk_entry_get_text (GTK_ENTRY (entry)), ""))
     gtk_entry_set_text (GTK_ENTRY (entry), "sip:");
 
   /* Packing widget */
@@ -1018,7 +1018,7 @@ audioev_filename_browse_cb (GtkWidget *b,
       if (filename) {
         sound_event = gm_conf_get_string (conf_key);
 
-        if (!sound_event || strcmp (filename, sound_event))
+        if (!sound_event || g_strcmp0 (filename, sound_event))
           gm_conf_set_string (conf_key, (gchar *) filename);
 
         g_free (filename);
