@@ -746,13 +746,13 @@ sch_parser_start_element (G_GNUC_UNUSED GMarkupParseContext *context,
 
   parser = (SchParser *)data;
   parser->state = START; /* default */
-  if (strcmp (element_name, "schema") == 0)
+  if (g_strcmp0 (element_name, "schema") == 0)
     parser->entry = entry_new ();
-  else if (strcmp (element_name, "applyto") == 0)
+  else if (g_strcmp0 (element_name, "applyto") == 0)
     parser->state = KEY;
-  else if (strcmp (element_name, "type") == 0)
+  else if (g_strcmp0 (element_name, "type") == 0)
     parser->state = TYPE;
-  else if (strcmp (element_name, "default") == 0)
+  else if (g_strcmp0 (element_name, "default") == 0)
     parser->state = VALUE;
 }
 
@@ -768,7 +768,7 @@ sch_parser_end_element (G_GNUC_UNUSED GMarkupParseContext *context,
 
   parser = (SchParser *)data;
 
-  if (strcmp (element_name, "schema") == 0) {
+  if (g_strcmp0 (element_name, "schema") == 0) {
     database_add_entry (parser->db, parser->entry);
     parser->entry = NULL;
   }
@@ -799,13 +799,13 @@ sch_parser_characters (G_GNUC_UNUSED GMarkupParseContext *context,
     entry_set_key (parser->entry, text);
     break;
   case TYPE:
-    if (strcmp (text, "bool") == 0)
+    if (g_strcmp0 (text, "bool") == 0)
       entry_set_type (parser->entry, GM_CONF_BOOL);
-    else if (strcmp (text, "int") == 0)
+    else if (g_strcmp0 (text, "int") == 0)
       entry_set_type (parser->entry, GM_CONF_INT);
-    else if (strcmp (text, "string") == 0)
+    else if (g_strcmp0 (text, "string") == 0)
       entry_set_type (parser->entry, GM_CONF_STRING);
-    else if (strcmp (text, "list") == 0)
+    else if (g_strcmp0 (text, "list") == 0)
       entry_set_type (parser->entry, GM_CONF_LIST);
     else
       entry_set_type (parser->entry, GM_CONF_OTHER);
@@ -1107,10 +1107,6 @@ gm_conf_load_user_conf (DataBase *db)
 
   filename = gm_conf_get_user_conf_filename ();
   result = database_load_file (db, filename);
-
-  if (! result)
-    g_log (G_LOG_DOMAIN, G_LOG_LEVEL_WARNING,
-	   "couldn't read the user configuration in %s", filename);
   g_free (filename);
 
   return result;
@@ -1125,13 +1121,11 @@ gm_conf_load_sys_conf (DataBase *db)
 
   g_return_val_if_fail (db != NULL, FALSE);
 
-  filename = g_build_filename (SYSCONFDIR, "ekiga",
-			       "ekiga.schemas", NULL);
+  filename = g_build_filename (SYSCONFDIR, "ekiga", "ekiga.schemas", NULL);
   result = database_load_file (db, filename);
 
   if (! result)
-    g_log (G_LOG_DOMAIN, G_LOG_LEVEL_WARNING,
-	   "couldn't read the system configuration in %s", filename);
+    g_error ("couldn't read the system configuration (ekiga.schemas) from %s", filename);
   g_free (filename);
 
   return result;
@@ -1156,13 +1150,10 @@ saveconf_timer_callback (G_GNUC_UNUSED gpointer unused)
 void
 gm_conf_init ()
 {
-  gboolean result = FALSE;
   DataBase *db = database_get_default ();
 
-  result = gm_conf_load_sys_conf (db);
-  result = (gm_conf_load_user_conf (db) || result);
-  if (!result)
-    g_warning ("Couldn't load system configuration");
+  gm_conf_load_sys_conf (db);
+  gm_conf_load_user_conf (db);
 
   /* those keys aren't found in gnomemeeting's schema */
   gm_conf_set_bool ("/desktop/gnome/interface/menus_have_icons", TRUE);
