@@ -39,11 +39,6 @@
 #ifndef GM_COMMON_H_
 #define GM_COMMON_H_
 
-#include <h323/h323.h>
-#include <sip/sip.h>
-
-#include <gtk/gtk.h>
-
 #define GENERAL_KEY         "/apps/" PACKAGE_NAME "/general/"
 #define USER_INTERFACE_KEY "/apps/" PACKAGE_NAME "/general/user_interface/"
 #define CONTACTS_KEY "/apps/" PACKAGE_NAME "/contacts/"
@@ -64,14 +59,4 @@
 #define AUDIO_CODECS_KEY "/apps/" PACKAGE_NAME "/codecs/audio/"
 #define VIDEO_CODECS_KEY  "/apps/" PACKAGE_NAME "/codecs/video/"
 
-/* Control Panel Section */
-typedef enum {
-
-  CONTACTS,
-  DIALPAD,
-  CALL,
-  NUM_SECTIONS
-} PanelSection;
-
-
 #endif /* GM_COMMON_H */
