@@ -43,6 +43,10 @@
 #include "common.h"
 #include "runtime.h"
 
+// FIXME: remove this include when the class won't have GetMainWindow and GetAssistantWindow anymore
+#include <gtk/gtk.h>
+
+#include <sip/sip.h>
 
 /**
  * COMMON NOTICE: The Application must be initialized with Init after its
@@ -103,10 +107,7 @@ class GnomeMeeting : public PProcess
 
   /* The different components of the GUI */
   GtkWidget *main_window;
-  GtkWidget *history_window;
   GtkWidget *assistant_window;
-  GtkWidget *prefs_window;
-  GtkWidget *accounts_window;
 
   static GnomeMeeting *GM;
 };
