@@ -173,7 +173,7 @@ update_combo_box (GtkComboBox         *combo_box,
 
   selected = 0;
   for (i = 0; options[i]; i++) {
-    if (default_value && strcmp (options[i], default_value) == 0)
+    if (default_value && g_strcmp0 (options[i], default_value) == 0)
       selected = i;
 
     gtk_list_store_append (GTK_LIST_STORE (model), &iter);
@@ -571,7 +571,7 @@ ekiga_net_info_changed_cb (G_GNUC_UNUSED GtkWidget *w,
   else {
     const char *username = gtk_entry_get_text (GTK_ENTRY (assistant->priv->username));
     const char *password = gtk_entry_get_text (GTK_ENTRY (assistant->priv->password));
-    complete = strcmp(username, "") != 0 && strcmp(password, "") != 0;
+    complete = g_strcmp0(username, "") != 0 && g_strcmp0(password, "") != 0;
   }
 
   set_current_page_complete (GTK_ASSISTANT (assistant), complete);
@@ -589,7 +589,7 @@ ekiga_out_info_changed_cb (G_GNUC_UNUSED GtkWidget *w,
   else {
     const char *username = gtk_entry_get_text (GTK_ENTRY (assistant->priv->dusername));
     const char *password = gtk_entry_get_text (GTK_ENTRY (assistant->priv->dpassword));
-    complete = strcmp(username, "") != 0 && strcmp(password, "") != 0;
+    complete = g_strcmp0(username, "") != 0 && g_strcmp0(password, "") != 0;
   }
 
   set_current_page_complete (GTK_ASSISTANT (assistant), complete);
@@ -1010,7 +1010,7 @@ create_audio_devices_page (EkigaAssistant *assistant)
   g_object_set (G_OBJECT (renderer),
                 "ellipsize-set", TRUE,
                 "ellipsize", PANGO_ELLIPSIZE_END, 
-                "width-chars", 45, NULL);
+                "width-chars", 65, NULL);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), assistant->priv->audio_ringer);
   gtk_box_pack_start (GTK_BOX (vbox), assistant->priv->audio_ringer, FALSE, FALSE, 0);
 
@@ -1041,7 +1041,7 @@ create_audio_devices_page (EkigaAssistant *assistant)
   g_object_set (G_OBJECT (renderer),
                 "ellipsize-set", TRUE,
                 "ellipsize", PANGO_ELLIPSIZE_END,
-                "width-chars", 45, NULL);
+                "width-chars", 65, NULL);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), assistant->priv->audio_player);
   gtk_box_pack_start (GTK_BOX (vbox), assistant->priv->audio_player, FALSE, FALSE, 0);
 
@@ -1072,7 +1072,7 @@ create_audio_devices_page (EkigaAssistant *assistant)
   g_object_set (G_OBJECT (renderer),
                 "ellipsize-set", TRUE,
                 "ellipsize", PANGO_ELLIPSIZE_END,
-                "width-chars", 45, NULL);
+                "width-chars", 65, NULL);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), assistant->priv->audio_recorder);
   gtk_box_pack_start (GTK_BOX (vbox), assistant->priv->audio_recorder, FALSE, FALSE, 0);
 
@@ -1190,7 +1190,7 @@ create_video_devices_page (EkigaAssistant *assistant)
   g_object_set (G_OBJECT (renderer),
                 "ellipsize-set", TRUE,
                 "ellipsize", PANGO_ELLIPSIZE_END,
-                "width-chars", 45, NULL);
+                "width-chars", 65, NULL);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), assistant->priv->video_device);
   gtk_box_pack_start (GTK_BOX (vbox), assistant->priv->video_device, FALSE, FALSE, 0);
 
@@ -1692,7 +1692,7 @@ ekiga_assistant_new (Ekiga::ServiceCore& service_core)
 
   conn = assistant->priv->audioinput_core->device_added.connect (boost::bind (&on_audioinput_device_added_cb, _1, _2, assistant));
   assistant->priv->connections.push_back (conn);
-  conn =assistant->priv-> audioinput_core->device_removed.connect (boost::bind (&on_audioinput_device_removed_cb, _1, _2, assistant));
+  conn = assistant->priv->audioinput_core->device_removed.connect (boost::bind (&on_audioinput_device_removed_cb, _1, _2, assistant));
   assistant->priv->connections.push_back (conn);
 
   conn = assistant->priv->audiooutput_core->device_added.connect (boost::bind (&on_audiooutput_device_added_cb, _1, _2, assistant));
