@@ -58,7 +58,7 @@ gnomemeeting_conf_upgrade ()
   gchar *conf_url = gm_conf_get_string ("/desktop/gnome/url-handlers/callto/command");
 
   if (!conf_url
-      || !strcmp (conf_url, "gnomemeeting -c \"%s\"")) {
+      || !g_strcmp0 (conf_url, "gnomemeeting -c \"%s\"")) {
 
     gm_conf_set_string ("/desktop/gnome/url-handlers/callto/command",
 			"ekiga -c \"%s\"");
@@ -72,7 +72,7 @@ gnomemeeting_conf_upgrade ()
 
   conf_url = gm_conf_get_string ("/desktop/gnome/url-handlers/h323/command");
   if (!conf_url
-      || !strcmp (conf_url, "gnomemeeting -c \"%s\"")) {
+      || !g_strcmp0 (conf_url, "gnomemeeting -c \"%s\"")) {
 
     gm_conf_set_string ("/desktop/gnome/url-handlers/h323/command",
                         "ekiga -c \"%s\"");
@@ -85,7 +85,7 @@ gnomemeeting_conf_upgrade ()
 
   conf_url = gm_conf_get_string ("/desktop/gnome/url-handlers/sip/command");
   if (!conf_url
-      || !strcmp (conf_url, "gnomemeeting -c \"%s\"")) {
+      || !g_strcmp0 (conf_url, "gnomemeeting -c \"%s\"")) {
 
     gm_conf_set_string ("/desktop/gnome/url-handlers/sip/command",
                         "ekiga -c \"%s\"");
@@ -98,13 +98,13 @@ gnomemeeting_conf_upgrade ()
 
   /* New full name key */
   conf_url = gm_conf_get_string (PERSONAL_DATA_KEY "full_name");
-  if (!conf_url || (conf_url && !strcmp (conf_url, ""))) {
+  if (!conf_url || (conf_url && !g_strcmp0 (conf_url, ""))) {
 
     gchar *fullname = NULL;
     gchar *firstname = gm_conf_get_string (PERSONAL_DATA_KEY "firstname");
     gchar *lastname = gm_conf_get_string (PERSONAL_DATA_KEY "lastname");
 
-    if (firstname && lastname && strcmp (firstname, "") && strcmp (lastname, "")) {
+    if (firstname && lastname && g_strcmp0 (firstname, "") && g_strcmp0 (lastname, "")) {
       fullname = g_strdup_printf ("%s %s", firstname, lastname);
       gm_conf_set_string (PERSONAL_DATA_KEY "firstname", "");
       gm_conf_set_string (PERSONAL_DATA_KEY "lastname", "");
@@ -119,14 +119,22 @@ gnomemeeting_conf_upgrade ()
   /* diamondcard is now set at sip.diamondcard.us */
   GSList *accounts = gm_conf_get_string_list ("/apps/" PACKAGE_NAME "/protocols/accounts_list");
   GSList *accounts_iter = accounts;
+  GRegex* regex = g_regex_new ("eugw\\.ast\\.diamondcard\\.us",
+			       (GRegexCompileFlags)0,
+			       (GRegexMatchFlags)0,
+			       NULL);
+  gchar* replaced_acct = NULL;
   while (accounts_iter) {
 
-    PString acct = (gchar *) accounts_iter->data;
-    acct.Replace ("eugw.ast.diamondcard.us", "sip.diamondcard.us", TRUE);
+    replaced_acct = g_regex_replace (regex, (gchar *) accounts_iter->data,
+				     -1, 0, "sip.diamondcard.us",
+				     (GRegexMatchFlags)0, NULL);
     g_free (accounts_iter->data);
-    accounts_iter->data = g_strdup ((const char *) acct);
+    accounts_iter->data = replaced_acct;
     accounts_iter = g_slist_next (accounts_iter);
   }
+  g_regex_unref (regex);
+
   gm_conf_set_string_list ("/apps/" PACKAGE_NAME "/protocols/accounts_list", accounts);
   g_slist_foreach (accounts, (GFunc) g_free, NULL);
   g_slist_free (accounts);
@@ -136,7 +144,7 @@ gnomemeeting_conf_upgrade ()
   gchar *device = NULL;
   gchar *new_device = NULL;
   plugin = gm_conf_get_string (AUDIO_DEVICES_KEY "plugin");
-  if (plugin && strcmp (plugin, "")) {
+  if (plugin && g_strcmp0 (plugin, "")) {
     device = gm_conf_get_string (AUDIO_DEVICES_KEY "input_device");
     new_device = g_strdup_printf ("%s (PTLIB/%s)", device, plugin);
     gm_conf_set_string (AUDIO_DEVICES_KEY "plugin", "");
@@ -162,7 +170,7 @@ gnomemeeting_conf_upgrade ()
 
   /* Video devices */
   plugin = gm_conf_get_string (VIDEO_DEVICES_KEY "plugin");
-  if (plugin && strcmp (plugin, "")) {
+  if (plugin && g_strcmp0 (plugin, "")) {
     device = gm_conf_get_string (VIDEO_DEVICES_KEY "input_device");
     new_device = g_strdup_printf ("%s (PTLIB/%s)", device, plugin);
     gm_conf_set_string (VIDEO_DEVICES_KEY "plugin", "");
@@ -190,9 +198,9 @@ gnomemeeting_conf_upgrade ()
 
   // migrate short_status
   gchar *ss = gm_conf_get_string (PERSONAL_DATA_KEY "short_status");
-  if (ss && !strcmp (ss, "online"))
+  if (ss && !g_strcmp0 (ss, "online"))
     gm_conf_set_string (PERSONAL_DATA_KEY "short_status", "available");
-  else if (ss && !strcmp (ss, "dnd"))
+  else if (ss && !g_strcmp0 (ss, "dnd"))
     gm_conf_set_string (PERSONAL_DATA_KEY "short_status", "busy");
   g_free (ss);
 
@@ -213,4 +221,14 @@ gnomemeeting_conf_upgrade ()
     g_slist_free (old_values);
     gm_conf_set_string_list (PERSONAL_DATA_KEY "dnd_custom_status", NULL);
   }
+
+  // migrate first port in UDP port ranges from 5060 to 5061, see bug #690621
+  if (version >= 0 && version <= 4000) {
+    gchar *ports = gm_conf_get_string (PORTS_KEY "udp_port_range");
+    if (ports && !g_ascii_strncasecmp (ports, "5060", 4)) {
+      ports[3] = '1';
+      gm_conf_set_string (PORTS_KEY "udp_port_range", ports);
+    }
+    g_free (ports);
+  }
 }
